@@ -331,6 +331,12 @@ char *
 export_preference_file_gmp (gvm_connection_t *, credentials_t *, params_t *,
                             cmd_response_data_t *);
 char *
+export_report_config_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                          cmd_response_data_t *);
+char *
+export_report_configs_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                           cmd_response_data_t *);
+char *
 export_report_format_gmp (gvm_connection_t *, credentials_t *, params_t *,
                           cmd_response_data_t *);
 char *
@@ -517,6 +523,22 @@ get_system_report_gmp_from_url (gvm_connection_t *, credentials_t *,
                                 const char *, params_t *,
                                 cmd_response_data_t *);
 
+char *
+get_report_config_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                       cmd_response_data_t *);
+char *
+get_report_configs_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                        cmd_response_data_t *);
+char *
+create_report_config_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                          cmd_response_data_t *);
+char *
+delete_report_config_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                          cmd_response_data_t *);
+char *
+save_report_config_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                        cmd_response_data_t *);
+
 char *
 get_report_format_gmp (gvm_connection_t *, credentials_t *, params_t *,
                        cmd_response_data_t *);
@@ -625,6 +647,60 @@ char *
 get_trash_gmp (gvm_connection_t *, credentials_t *, params_t *params,
                cmd_response_data_t *);
 char *
+get_trash_alerts_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                      cmd_response_data_t *);
+char *
+get_trash_configs_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                       cmd_response_data_t *);
+char *
+get_trash_credentials_gmp (gvm_connection_t *, credentials_t *,
+                           params_t *params, cmd_response_data_t *);
+char *
+get_trash_filters_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                       cmd_response_data_t *);
+char *
+get_trash_groups_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                      cmd_response_data_t *);
+char *
+get_trash_notes_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                     cmd_response_data_t *);
+char *
+get_trash_overrides_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                         cmd_response_data_t *);
+char *
+get_trash_permissions_gmp (gvm_connection_t *, credentials_t *,
+                           params_t *params, cmd_response_data_t *);
+char *
+get_trash_port_lists_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                          cmd_response_data_t *);
+char *
+get_trash_report_configs_gmp (gvm_connection_t *, credentials_t *,
+                              params_t *params, cmd_response_data_t *);
+char *
+get_trash_report_formats_gmp (gvm_connection_t *, credentials_t *,
+                              params_t *params, cmd_response_data_t *);
+char *
+get_trash_roles_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                     cmd_response_data_t *);
+char *
+get_trash_scanners_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                        cmd_response_data_t *);
+char *
+get_trash_schedules_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                         cmd_response_data_t *);
+char *
+get_trash_tags_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                    cmd_response_data_t *);
+char *
+get_trash_targets_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                       cmd_response_data_t *);
+char *
+get_trash_tasks_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                     cmd_response_data_t *);
+char *
+get_trash_tickets_gmp (gvm_connection_t *, credentials_t *, params_t *params,
+                       cmd_response_data_t *);
+char *
 restore_gmp (gvm_connection_t *, credentials_t *, params_t *,
              cmd_response_data_t *);
 char *
