@@ -311,7 +311,7 @@ init_validator ()
   gvm_validator_add (validator, "credential_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "create_credentials_type", "^(gen|pass|key)$");
   gvm_validator_add (validator, "credential_type",
-                     "^(cc|up|usk|smime|pgp|snmp|pw)$");
+                     "^(cc|up|usk|smime|pgp|snmp|krb5|pw)$");
   gvm_validator_add (validator, "credential_login", "^[-_[:alnum:]\\.@\\\\]*$");
   gvm_validator_add (validator, "condition_data:name", "^.*$");
   gvm_validator_add (validator, "condition_data:value", "(?s)^.*$");
@@ -397,7 +397,6 @@ init_validator ()
                      "^(Browser Language|"
                      "([a-z]{2,3})(_[A-Z]{2})?(@[[:alnum:]_-]+)?"
                      "(:([a-z]{2,3})(_[A-Z]{2})?(@[[:alnum:]_-]+)?)*)$");
-  gvm_validator_add (validator, "levels", "^(h|m|l|g|f){0,5}$");
   gvm_validator_add (validator, "list_fname",
                      "^([[:alnum:]_-]|%[%CcDFMmNTtUu])+$");
   /* Used for users, credentials, and scanner login name. */
@@ -441,11 +440,13 @@ init_validator ()
   gvm_validator_add (validator, "definitions_file", "(?s)^.*$");
   gvm_validator_add (validator, "ca_pub", "(?s)^.*$");
   gvm_validator_add (validator, "which_cert", "^(default|existing|new)$");
+  gvm_validator_add (validator, "kdc", "(?s)^.*$");
   gvm_validator_add (validator, "key_pub", "(?s)^.*$");
   gvm_validator_add (validator, "key_priv", "(?s)^.*$");
   gvm_validator_add (validator, "radiuskey", "^.*$");
   gvm_validator_add (validator, "range_type",
                      "^(duration|until_end|from_start|start_to_end)$");
+  gvm_validator_add (validator, "realm", "(?s)^.*$");
   gvm_validator_add (validator, "related:name", "^.*$");
   gvm_validator_add (validator, "related:value", "^.*$");
   gvm_validator_add (validator, "report_fname",
@@ -501,8 +502,6 @@ init_validator ()
   gvm_validator_add (validator, "text", "^.*");
   gvm_validator_add (validator, "text_columns:name", "^[0123456789]+$");
   gvm_validator_add (validator, "text_columns:value", "^[_[:alnum:]]+$");
-  gvm_validator_add (validator, "threat",
-                     "^(High|Medium|Low|Alarm|Log|False Positive|)$");
   gvm_validator_add (validator, "ticket_status", "^(Open|Fixed|Closed)$");
   gvm_validator_add (validator, "trend", "^(0|1)$");
   gvm_validator_add (validator, "trend:value", "^(0|1)$");
@@ -643,7 +642,6 @@ init_validator ()
   gvm_validator_alias (validator, "new_severity", "severity_optional");
   gvm_validator_alias (validator, "new_severity_from_list",
                        "severity_optional");
-  gvm_validator_alias (validator, "new_threat", "threat");
   gvm_validator_alias (validator, "next", "page");
   gvm_validator_alias (validator, "next_next", "page");
   gvm_validator_alias (validator, "next_error", "page");
@@ -707,6 +705,7 @@ init_validator ()
   gvm_validator_alias (validator, "show_all", "boolean");
   gvm_validator_alias (validator, "slave_id", "id");
   gvm_validator_alias (validator, "smb_credential_id", "credential_id");
+  gvm_validator_alias (validator, "krb5_credential_id", "credential_id");
   gvm_validator_alias (validator, "snmp_credential_id", "credential_id");
   gvm_validator_alias (validator, "ssh_credential_id", "credential_id");
   gvm_validator_alias (validator, "ssh_elevate_credential_id", "credential_id");
